/* ToneMatrix - main.c
 * Copyright (c) 2011 Tanner Babcock */
#include <oslib/oslib.h>
#include <pspkernel.h>
#include <psputils.h>
#include "main.h"
PSP_MODULE_INFO("ToneMatrix", 0, 1, 1);
PSP_MAIN_THREAD_ATTR(THREAD_ATTR_USER | THREAD_ATTR_VFPU);
PSP_HEAP_SIZE_KB(-2048);

void tmMainloop(void) {
	int x = 0, y = 0, m;
	clock_t start, current, d;
	oslClearScreen(RGBA(0, 0, 0, 255));
	start = sceKernelLibcClock();
	while (!osl_quit) {
		oslStartDrawing();
		oslReadKeys();
		oslClearScreen(RGBA(0, 0, 0, 255));
		tmDrawgrid();
		current = sceKernelLibcClock();
		d = (current - start);
		// grid[x][y] is where the cursor is
		if (grid[x][y] == ON)
			grid[x][y] = CURSON;
		else if (grid[x][y] == OFF)
			grid[x][y] = CURSOFF;
		if (x > 16 || x < 0)
			x = 0;
		if (y > 8 || y < 0)
			y = 0;
		if (osl_keys->pressed.up) {
			if (y > 0) {
				if (grid[x][y] == CURSON) {
					grid[x][y] = ON;
					grid[x][y-1] = CURSON;
				}
				if (grid[x][y] == CURSOFF) {
					grid[x][y] = OFF;
					grid[x][y-1] = CURSOFF;
				}
				y--;
			}
		}
		if (osl_keys->pressed.down) {
			if (y < 7) {
				if (grid[x][y] == CURSON) {
					grid[x][y] = ON;
					grid[x][y+1] = CURSON;
				}
				if (grid[x][y] == CURSOFF) {
					grid[x][y] = OFF;
					grid[x][y+1] = CURSOFF;
				}
				y++;
			}
		}
		if (osl_keys->pressed.left) {
			if (x > 0) {
				if (grid[x][y] == CURSON) {
					grid[x][y] = ON;
					grid[x-1][y] = CURSON;
				}
				if (grid[x][y] == CURSOFF) {
					grid[x][y] = OFF;
					grid[x-1][y] = CURSOFF;
				}
				x--;
			}
		}
		if (osl_keys->pressed.right) {
			if (x < 15) {
				if (grid[x][y] == CURSON) {
					grid[x][y] = ON;
					grid[x+1][y] = CURSON;
				}
				if (grid[x][y] == CURSOFF) {
					grid[x][y] = OFF;
					grid[x+1][y] = CURSOFF;
				}
				x++;
			}
		}
		if (osl_keys->pressed.cross) {
			if (grid[x][y] == CURSOFF)
				grid[x][y] = CURSON;
			else if (grid[x][y] == CURSON)
				grid[x][y] = CURSOFF;
		}
		if (osl_keys->pressed.circle) {
			isplaying = (isplaying == TRUE) ? FALSE : TRUE;
			col = 0;
			if (isplaying == FALSE)
				sceKernelTerminateThread(soundloop);
			else if (isplaying == TRUE)
				sceKernelStartThread(soundloop, 0, NULL);
		}
		if (osl_keys->pressed.triangle) {
			tmClear();
			x = 0, y = 0;
		}
		if (osl_keys->pressed.start) {
			switch (tmMenu()) {
				case STOPM:
					isplaying = (isplaying == TRUE) ? FALSE : TRUE;
					col = 0;
					if (isplaying == FALSE)
						sceKernelTerminateThread(soundloop);
					else if (isplaying == TRUE)
						sceKernelStartThread(soundloop, 0, NULL);
					break;
				case HELPM:
					tmHelp();
					break;
				case CLEARM:
					tmClear();
					x = 0, y = 0;
					break;
				case QUITM:
					goto exit;
					break;
			}
		}
		if (osl_keys->pressed.select)
			tmHelp();
		oslEndDrawing();
		oslSyncFrame();
	}
	exit:
	quit = TRUE;
	return;
}

int main(void) {
	tmInit();
	sceKernelStartThread(soundloop, 0, NULL);
	tmMainloop();
	oslEndGfx();
	oslQuit();
	return 0;
}
